@@ -9,31 +9,30 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General 
- * Public License along with this library; if not, write to the 
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include <glib.h>
+#include "font-thumbnailer-provider.h"
+#include "font-thumbnailer.h"
+
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <tumbler/tumbler.h>
-
-#include <font-thumbnailer/font-thumbnailer-provider.h>
-#include <font-thumbnailer/font-thumbnailer.h>
 
 
-
-static void   font_thumbnailer_provider_thumbnailer_provider_init (TumblerThumbnailerProviderIface *iface);
-static GList *font_thumbnailer_provider_get_thumbnailers          (TumblerThumbnailerProvider      *provider);
+static void
+font_thumbnailer_provider_thumbnailer_provider_init (TumblerThumbnailerProviderIface *iface);
+static GList *
+font_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provider);
 
 
 
@@ -93,24 +92,23 @@ font_thumbnailer_provider_init (FontThumbnailerProvider *provider)
 static GList *
 font_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provider)
 {
-  static const gchar *mime_types[] = 
-  { 
+  static const gchar *mime_types[] = {
     "application/x-font-otf",
     "application/x-font-pcf",
     "application/x-font-ttf",
     "application/x-font-type1",
     NULL,
   };
-  FontThumbnailer    *thumbnailer;
-  GList              *thumbnailers = NULL;
-  GStrv               uri_schemes;
+  FontThumbnailer *thumbnailer;
+  GList *thumbnailers = NULL;
+  GStrv uri_schemes;
 
   /* determine the URI schemes supported by GIO */
   uri_schemes = tumbler_util_get_supported_uri_schemes ();
 
   /* create the pixbuf thumbnailer */
   thumbnailer = g_object_new (FONT_TYPE_THUMBNAILER,
-                              "uri-schemes", uri_schemes, "mime-types", mime_types, 
+                              "uri-schemes", uri_schemes, "mime-types", mime_types,
                               NULL);
 
   /* add the thumbnailer to the list */
